--[[
	Title: AI Helpers
]]


--[[
	Function: playScene

	Plays a scripted scene through a npc

	Parameters:

		npc - The npc entity
		scene - The scene to play

]]
function ULib.playScene ( npc, scene )
	_EntFire( npc, "setexpressionoverride", scene, 0 )
end


--[[
	Function: stopScene

	Stops an npc playing a scene

	Parameters:

		npc - The npc entity

]]
function ULib.stopScene ( npc )
	_EntFire( npc, "setexpressionoverride", "shush", 0 )
end


--[[
	Function: goToPosition

	Forces a npc to walk to a position

	Parameters:

		npc - The npc entity
		position - The position

]]
function ULib.goToPosition ( npc, pos )
	_npc.SetLastPosition( npc, pos )
	_npc.SetSchedule( npc, SCHED_FORCED_GO_RUN )
end


--[[
	Function: followEnt

	Forces a npc to follow another entity ( ie, a player ).

	Parameters:

		npc - The npc entity.
		targetent - The ent to follow.

	Note:
	
		This seems to be a bit buggy, but should work okay if you're careful.
]]
local gNpcs = {}
local gTimerid

function ULib.followEnt ( npc, targetent )
	if not gTimerid then gTimerid = AddTimer( 2, 0, ULib.npcUpdate ) end -- Only add the timer when required.
	gNpcs[ npc ] = targetent
end


--[[
	Function: npcUpdate
	
	*This function is for internal use only*. It updates entity movement to support <followEnt()>
]]
function ULib.npcUpdate()
	for k, v in pairs( gNpcs ) do
		local look = _EntGetAng( v )
		look.z = 0
		look = vecNormalize( look )
		local pos = vecSub( _EntGetPos( v ), vecMul( look, 100 ) )
		ULib.goToPosition( k, pos )
	end
end
